==> tdiary_2.0.0.orig.tar.gz: tdiary-2.0.0/misc/plugin/ja/referer_scheme.rb <==
=begin
= Meta-scheme plugin((-$Id: referer_scheme.rb,v 1.6 2004/02/26 08:09:24 tadatadashi Exp $-))
Υ󥯸ִꥹȤεҤڤˤޤ

== ˡ
Υץ饰򡢥ץ饰Υǥ쥯ȥ뤫ץ饰ץ饰
󤫤ͭˤƤ

ˡꡢ󥯸顢󥯸ִꥹȤԽơtdiary:
hatena:Ȥץեå(᥿ȸƤ֤Ȥˤޤ)URL
դƤ

ˤꡢդִ롼񤫤ʤǤ⡢ִʸ˼ưŪ
դʤɤ뤳ȤǤޤ

㤨СΤ褦ʵҤ򤷤Ƥ
* tdiary:http://tdiary.tdiary.net/ tDiary.net
* tdiarynet:foo((-http://foo.tdiary.net/Ÿޤ-)) foo
* hatena:bar((-http://d.hatena.ne.jp/bar/Ÿޤ-)) bar
ǤϡURLդޤޤС(YYYY-MM-DD)Ȥɲäޤ

== 
tdiary:ǻϤޤURLϡ
* ̤ȤʤǤ
* /ǽ餻Ƥ

tdiarynet:hatena:ǻϤޤURLϡ
* ̤ȤʤǤ
* URLȤƤϥ桼IDꤷƤ

== ᥿κ
󥯸ִꥹȤURLɽʸФơ/^(\w+):/Ȥɽ
ǰפʸ󤬥᥿ȤƸФޤ
  def scheme_̾( url, name )
    :
    yield( url_variants, name_variants )
    :
  end
Ȥ@conf.referer_tableðۥ᥽åɤ򥤥ƥ졼ȤƤС
ִꥹȤεҤ˱ƤΥ᥽åɤƤФޤurlˤ
֥᥿̾:פɽϤ뤳ȤդƤ

== Copyright
Copyright (C) 2003 zunda <zunda at freeshell.org>

Permission is granted for use, copying, modification, distribution, and
distribution of modified versions of this work under the terms of GPL
version 2 or later.
=end

unless @conf.referer_table.respond_to?( 'scheme_tdiarynet', true ) then
	class << @conf.referer_table
	private
		TdiaryNet = '.tdiary.net/'
	
		def scheme_tdiarynet( url, name )
			TdiaryDates.each do |a|
				yield( "http://#{url}#{TdiaryNet}#{a[0]}", name + a[1] )
			end
			yield( "http://#{url}#{TdiaryNet}.*", name )
		end
	end
end

unless @conf.referer_table.respond_to?( 'scheme_hatena', true ) then
	class << @conf.referer_table
		HatenaHost = 'http://d.hatena.ne.jp/'
		def scheme_hatena( url, name )
			[
				['(\d{4})(\d{2})(\d{2}).*', '(\1-\2-\3)'],
				['(\d{4})(\d{2}).*', '(\1-\2)'],
			].each do |a|
				yield( "#{HatenaHost}#{url}/#{a[0]}", name + a[1] )
			end
			yield( "#{HatenaHost}#{url}/.*", name )
		end
	end
end

==> tdiary_2.0.2+20050720.orig.tar.gz: tdiary-2.0.2/misc/plugin/ja/referer_scheme.rb <==
=begin
= Meta-scheme plugin((-$Id: referer_scheme.rb,v 1.8 2004/07/30 18:38:33 zunda Exp $-))
Υ󥯸ִꥹȤεҤڤˤޤ

== ˡ
Υץ饰򡢥ץ饰Υǥ쥯ȥ뤫ץ饰ץ饰
󤫤ͭˤƤ

ˡꡢ󥯸顢󥯸ִꥹȤԽơtdiary:
hatena:Ȥץեå(᥿ȸƤ֤Ȥˤޤ)URL
դƤ

ˤꡢդִ롼񤫤ʤǤ⡢ִʸ˼ưŪ
դʤɤ뤳ȤǤޤ

㤨СΤ褦ʵҤ򤷤Ƥ
* tdiary:http://tdiary.tdiary.net/ tDiary.net
* tdiarynet:foo((-http://foo.tdiary.net/Ÿޤ-)) foo
* hatena:bar((-http://d.hatena.ne.jp/bar/Ÿޤ-)) bar
ǤϡURLդޤޤС(YYYY-MM-DD)Ȥɲäޤ

== 
tdiary:ǻϤޤURLϡ
* ̤ȤʤǤ
* /ǽ餻Ƥ

tdiarynet:hatena:ǻϤޤURLϡ
* ̤ȤʤǤ
* URLȤƤϥ桼IDꤷƤ

== ᥿κ
󥯸ִꥹȤURLɽʸФơ/^(\w+):/Ȥɽ
ǰפʸ󤬥᥿ȤƸФޤ
  def scheme_̾( url, name )
    :
    yield( url_variants, name_variants )
    :
  end
Ȥ@conf.referer_tableðۥ᥽åɤ򥤥ƥ졼ȤƤС
ִꥹȤεҤ˱ƤΥ᥽åɤƤФޤurlˤ
֥᥿̾:פɽϤ뤳ȤդƤ

== Copyright
Copyright (C) 2003 zunda <zunda at freeshell.org>

Permission is granted for use, copying, modification, distribution, and
distribution of modified versions of this work under the terms of GPL
version 2 or later.
=end

unless @conf.referer_table.respond_to?( 'scheme_tdiarynet', true ) then
	class << @conf.referer_table
	private
		TdiaryNet = '\.tdiary\.net/'
	
		def scheme_tdiarynet( url, name )
			TdiaryDates.each do |a|
				yield( "http://#{url}#{TdiaryNet}#{a[0]}", name + a[1] )
			end
			yield( "http://#{url}#{TdiaryNet}.*", name )
		end
	end
end

unless @conf.referer_table.respond_to?( 'scheme_hatena', true ) then
	class << @conf.referer_table
		HatenaHost = 'http://d(?:iary)?\.hatena\.ne\.jp/'
		def scheme_hatena( url, name )
			[
				['(\d{4})(\d{2})(\d{2}).*', '(\1-\2-\3)'],
				['(\d{4})(\d{2}).*', '(\1-\2)'],
			].each do |a|
				yield( "#{HatenaHost}#{url}/#{a[0]}", name + a[1] )
			end
			yield( "#{HatenaHost}#{url}/.*", name )
		end
	end
end
